@@ -11,20 +11,22 @@
 #' @export
 #' @references \url{http://docs.aws.amazon.com/AlexaWebInfoService/latest/ApiReference_SitesLinkingInAction.html}
 #' @examples \dontrun{
-#' in_links(url="google.com")
+#' in_links(url = "google.com")
 #' }
 
 in_links <- function(url = NULL, start = 0, count = 20, ...) {
-   
-    if (!is.character(url)) {
-        stop("Please specify a valid url")
-    }
 
-    query <-  list(Action = "SitesLinkingIn", ResponseGroup="SitesLinkingIn", Url = url, Start = start, Count = count)
+  if (!is.character(url)) {
+    stop("Please specify a valid url")
+  }
 
-    insite_links_payload <- alexa_GET(query, ...)
+  query <-  list(Action = "SitesLinkingIn", ResponseGroup = "SitesLinkingIn",
+                                        Url = url, Start = start, Count = count)
 
-    res <- do.call(rbind, lapply(insite_links_payload[[2]][[1]][[1]], unlist))
-    res_df <- as.data.frame(res, row.names=1:length(res))
-    names(res_df) <- c("title", "url")
+  insite_links_payload <- alexa_GET(query, ...)
+
+  res <- ldply(lapply(insite_links_payload[[2]][[1]][[1]], unlist), rbind)
+  names(res) <- tolower(names(res))
+
+  res
 }
